﻿using System;
using System.Collections.Generic;

namespace IMMeDotNet {
	partial class Host {

		/// <summary>
		/// Used to generate a message ID.
		/// </summary>
		private byte messageCounter = 0;

		/// <summary>
		/// Stores the outgoing message until they have been acknowledged.
		/// </summary>
		private Dictionary<uint, Message> outbox = new Dictionary<uint, Message>();

		/// <summary>
		/// Maps last received message IDs to contacts.
		/// </summary>
		private Dictionary<uint, KeyValuePair<Contact, Contact>> messageToContactMap = new Dictionary<uint, KeyValuePair<Contact, Contact>>();

		/// <summary>
		/// Used to generate text message IDs.
		/// </summary>
		private Random textIDGenerator = new Random((int)(DateTime.Now.Ticks / (uint)1E7));

		/// <summary>
		/// Sends a <see cref="Message"/>.
		/// </summary>
		/// <param name="message">The <see cref="Message"/> to send.</param>
		public void SendMessage(Message message) {

			// Creates an ID for the text message.
			uint textID;
			lock (outbox) {
				do {
					textID = (uint)textIDGenerator.Next();
				} while (outbox.ContainsKey(textID) || messageToContactMap.ContainsKey(textID));
				outbox.Add(textID, message);
			}

			var textMessage = new OutgoingUsbMessage(0x00, 0x06, 0x02);

			while (++messageCounter == 0) ;
			textMessage.Write(messageCounter);
			textMessage.Write((byte)0x01);

			textMessage.Write(message.Recipient.ID);
			textMessage.Write((uint)textID);
			textMessage.Write(message.Sender.ID);
			
			textMessage.Write(message.Text);
			
			this.Write(textMessage);
		}

	}
}
