﻿using System;
using System.Collections.Generic;
using System.Text;

namespace IMMeDotNet {
	class Program {

		static void Main() {

			using (var testHost = new Host()) {

				var contacts = new List<Contact>();
				contacts.Add(new Contact("Alice"));
				contacts.Add(new Contact("Bob"));

				testHost.AttemptedLogIn += (sender, e) => {
					Console.WriteLine("{0} tried to log in (password: {1}).", e.Contact.Username, e.Password);
					e.Success = e.Password == e.Contact.Username;
				};
				testHost.LogIn += (sender, e) => {
					Console.WriteLine(e.Contact.Username + " logged in.");
				};
				testHost.LogOff += (sender, e) => {
					Console.WriteLine(e.Contact.Username + " logged out.");
				};
				testHost.RequestFriendList += (sender, e) => {
					Console.WriteLine(e.Contact.Username + " requested contact list.");
					e.Friends = contacts.ToArray();
				};
				testHost.RequestOnlineFriendList += (sender, e) => {
					Console.WriteLine(e.Contact.Username + " requested online contact list.");
					e.Friends = contacts.ToArray();
				};
				testHost.FriendRemoved += (sender, e) => {
					contacts.Remove(e.Friend);
					Console.WriteLine(e.Friend.Username + " has been removed from the friend list of " + e.Contact.Username);
				};
				testHost.FriendAdded += (sender, e) => {
					contacts.Add(e.Friend);
					Console.WriteLine(e.Friend.Username + " has been added to the friend list of " + e.Contact.Username);
				};
				testHost.MessageReceived += (sender, e) => {
					Console.WriteLine("[In] {0}->{1} : {2}", e.Message.Sender.Username, e.Message.Recipient.Username, e.Message.Text);
					testHost.SendMessage(new Message(e.Message.Recipient, e.Message.Sender, new IMMeString(string.Format("'{0}' @ {1}", e.Message.Text, DateTime.Now.ToLongTimeString()))));
				};
				testHost.MessageSent += (sender, e) => {
					Console.WriteLine("[Out] {0}->{1} : {2}", e.Message.Sender.Username, e.Message.Recipient.Username, e.Message.Text);
				};
				testHost.DiscussionEnded += (sender, e) => {
					Console.WriteLine("Discussion ended between {0} and {1}.", e.Contact.Username, e.Friend.Username);
				};
				Console.ReadKey(true);
			}
		}
	}
}
